rule win_laziok_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.laziok."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.laziok"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85f6 740b 837c240cff 8937 7502 }
            // n = 5, score = 900
            //   85f6                 | test                esi, esi
            //   740b                 | je                  0xd
            //   837c240cff           | cmp                 dword ptr [esp + 0xc], -1
            //   8937                 | mov                 dword ptr [edi], esi
            //   7502                 | jne                 4

        $sequence_1 = { 47 68???????? 57 e8???????? 8bf0 59 }
            // n = 6, score = 900
            //   47                   | inc                 edi
            //   68????????           |                     
            //   57                   | push                edi
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   59                   | pop                 ecx

        $sequence_2 = { 8d85f4fdffff 50 e8???????? 33c0 668945fc }
            // n = 5, score = 900
            //   8d85f4fdffff         | lea                 eax, [ebp - 0x20c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   33c0                 | xor                 eax, eax
            //   668945fc             | mov                 word ptr [ebp - 4], ax

        $sequence_3 = { 68ffffff1f 52 e8???????? 83c410 c3 }
            // n = 5, score = 900
            //   68ffffff1f           | push                0x1fffffff
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   c3                   | ret                 

        $sequence_4 = { e8???????? 83c420 5b c20400 }
            // n = 4, score = 900
            //   e8????????           |                     
            //   83c420               | add                 esp, 0x20
            //   5b                   | pop                 ebx
            //   c20400               | ret                 4

        $sequence_5 = { 56 8b7508 833e01 7513 6a00 ff7510 ff750c }
            // n = 7, score = 900
            //   56                   | push                esi
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   833e01               | cmp                 dword ptr [esi], 1
            //   7513                 | jne                 0x15
            //   6a00                 | push                0
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_6 = { 39742410 741b ff742410 ff15???????? 8bf0 }
            // n = 5, score = 900
            //   39742410             | cmp                 dword ptr [esp + 0x10], esi
            //   741b                 | je                  0x1d
            //   ff742410             | push                dword ptr [esp + 0x10]
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_7 = { 56 57 ff74240c 33f6 ff35???????? e8???????? }
            // n = 6, score = 900
            //   56                   | push                esi
            //   57                   | push                edi
            //   ff74240c             | push                dword ptr [esp + 0xc]
            //   33f6                 | xor                 esi, esi
            //   ff35????????         |                     
            //   e8????????           |                     

    condition:
        7 of them and filesize < 688128
}